netapp_ontap.models.shelf_bays API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.shelf_bays`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ShelfBaysSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ShelfBays object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `has_disk GET POST PATCH`

    The has_disk field of the shelf_bays.

  `id GET POST PATCH`

    The id field of the shelf_bays.

    Example: 0

  `state GET POST PATCH`

    The state field of the shelf_bays.

    Valid choices:

    - unknown
    - ok
    - error
  `type GET POST PATCH`

    The type field of the shelf_bays.

    Valid choices:

    - unknown
    - single_disk
    - multi_lun